{% load i18n %}
{% load url from future %}
<h2>{{ enquiry.get_translation }}</h2>
<a href="{% url "enquiry_detail" pk=enquiry.pk %}">{% trans "Vote now!" %}</a>
<ul>
    {% for answer_translated in enquiry.get_answers %}
        <li>{{ answer_translated }} {{ answer_translated.answer.get_vote_count }} {% trans "votes" %}</li>
    {% endfor %}
</ul>